# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import enum

import winrt.system
from winui3._winui3_microsoft_windows_system_power import (
    PowerManager,
)

__all__ = [
    "BatteryStatus",
    "DisplayStatus",
    "EffectivePowerMode",
    "EnergySaverStatus",
    "PowerSourceKind",
    "PowerSupplyStatus",
    "SystemSuspendStatus",
    "UserPresenceStatus",
    "PowerManager",
]

class BatteryStatus(enum.IntEnum):
    NOT_PRESENT = 0
    DISCHARGING = 1
    IDLE = 2
    CHARGING = 3

class DisplayStatus(enum.IntEnum):
    OFF = 0
    ON = 1
    DIMMED = 2

class EffectivePowerMode(enum.IntEnum):
    BATTERY_SAVER = 0
    BETTER_BATTERY = 1
    BALANCED = 2
    HIGH_PERFORMANCE = 3
    MAX_PERFORMANCE = 4
    GAME_MODE = 5
    MIXED_REALITY = 6

class EnergySaverStatus(enum.IntEnum):
    UNINITIALIZED = 0
    DISABLED = 1
    OFF = 2
    ON = 3

class PowerSourceKind(enum.IntEnum):
    AC = 0
    DC = 1

class PowerSupplyStatus(enum.IntEnum):
    NOT_PRESENT = 0
    INADEQUATE = 1
    ADEQUATE = 2

class SystemSuspendStatus(enum.IntEnum):
    UNINITIALIZED = 0
    ENTERING = 1
    AUTO_RESUME = 2
    MANUAL_RESUME = 3

class UserPresenceStatus(enum.IntEnum):
    PRESENT = 0
    ABSENT = 1

